@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -381,10 +381,12 @@ public class IMAPAuthentication implements AuthenticationService {
                         com.openexchange.configuration.ConfigurationException.Code.NOT_READABLE,
                         file.getAbsolutePath());
                 } finally {
-                    try {
-                        fis.close();
-                    } catch (final IOException e) {
-                        LOG.error("Error closing file inputstream for file " + IMAP_AUTH_PROPERTY_FILE + " ", e);
+                    if (null != fis) {
+                        try {
+                            fis.close();
+                        } catch (final IOException e) {
+                            LOG.error("Error closing file inputstream for file " + IMAP_AUTH_PROPERTY_FILE + " ", e);
+                        }
                     }
                 }
             }
@@ -394,21 +396,20 @@ public class IMAPAuthentication implements AuthenticationService {
     /**
      * Splits user name and context.
      * 
-     * @param loginInfo combined information seperated by an @ sign.
+     * @param loginInfo combined information separated by an @ sign.
      * @return a string array with context and user name (in this order).
-     * @throws LoginException if no seperator is found.
      */
-    private String[] split(final String loginInfo) throws LoginException {
+    private String[] split(final String loginInfo) {
         return split(loginInfo, '@');
     }
 
     /**
      * Splits user name and context.
      * 
-     * @param loginInfo combined information seperated by an @ sign.
-     * @param separator for spliting user name and context.
+     * @param loginInfo combined information separated by an @ sign.
+     * @param separator for splitting user name and context.
      * @return a string array with context and user name (in this order).
-     * @throws LoginException if no seperator is found.
+     * @throws LoginException if no separator is found.
      */
     private String[] split(final String loginInfo, final char separator) {
         final int pos = loginInfo.lastIndexOf(separator);
